@@ -5,13 +5,13 @@ from .handler import (
     pre_handler,
     bind_handler,
     info_handler,
-    recent_handler,
-    best_handler,
     help_handler,
     random_handler,
     song_handler,
     default_handler,
     preview_handler,
+    ptt_handler,
+    ui_handler,
 )
 from nonebot.plugin import PluginMetadata
 
@@ -22,14 +22,12 @@ __plugin_meta__ = PluginMetadata(
     extra={
         "unique_name": "arcaeabot",
         "author": "SEAFHMC <soku_ritsuki@outlook.com>",
-        "version": "3.0.3",
+        "version": "3.1.3",
     },
 )
 
 arc.handle()(pre_handler)
 arc.handle()(b30_handler)
-arc.handle()(recent_handler)
-arc.handle()(best_handler)
 arc.handle()(song_handler)
 arc.handle()(preview_handler)
 arc.handle()(bind_handler)
@@ -37,4 +35,6 @@ arc.handle()(info_handler)
 arc.handle()(assets_update_handler)
 arc.handle()(help_handler)
 arc.handle()(random_handler)
+arc.handle()(ptt_handler)
+arc.handle()(ui_handler)
 arc.handle()(default_handler)
