@@ -1,6 +1,6 @@
 from ..matcher import arc
-from ..assets_updater import check_song_update, check_char_update
-from ..resource_manager import assets_root
+from ..assets_updater import AssetsUpdater
+from ..resource_manager import db_root as ROOT
 from nonebot.adapters.onebot.v11.event import MessageEvent
 from nonebot.adapters.onebot.v11.message import Message, MessageSegment
 from nonebot.params import CommandArg
@@ -13,15 +13,12 @@ async def assets_update_handler(event: MessageEvent, arg: Message = CommandArg()
     args: List = arg.extract_plain_text().split()
     if args[0] == "assets_update":
         if len(args) == 2:
-            if args[1] == "--purge":
-                if path.exists(assets_root / "song"):
-                    rmtree(assets_root / "song")
-                if path.exists(assets_root / "char"):
-                    rmtree(assets_root / "char")
+            if args[1] == "-purge":
+                rmtree(ROOT / "assets", ignore_errors=True)
         await arc.send("正在更新，请关注控制台更新进度…")
 
-        result_song = await check_song_update()
-        result_char = await check_char_update()
+        result_song = await AssetsUpdater.check_song_update()
+        result_char = await AssetsUpdater.check_char_update()
 
         await arc.finish(
             MessageSegment.reply(event.message_id)
