@@ -1,4 +1,4 @@
-from nonebot.adapters.onebot.v11 import Bot, MessageEvent, Message, MessageSegment
+from nonebot.adapters.onebot.v11 import MessageEvent, Message, MessageSegment
 from nonebot.params import CommandArg
 from ..matcher import arc
 from ..message.text_message import TextMessage
@@ -13,7 +13,8 @@ async def song_handler(event: MessageEvent, arg: Message = CommandArg()):
     args = arg.extract_plain_text().split()
     if len(args) >= 2 and args[0] == "song":
         # get args
-        if difficulty := diffstr2num(args[-1].upper()):
+        difficulty = diffstr2num(args[-1].upper())
+        if difficulty is not None:
             songname = " ".join(args[1:-1])
         else:
             difficulty = -1
